JBossWS SVN: r19599 - spi/trunk/src/main/java/org/jboss/wsf/spi/deployment.
by jbossws-commits@lists.jboss.org
Author: rsearls
Date: 2015-03-24 13:58:25 -0400 (Tue, 24 Mar 2015)
New Revision: 19599
Modified:
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java
Log:
[JBWS-3878] removed unintended methods
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java 2015-03-23 18:41:32 UTC (rev 19598)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java 2015-03-24 17:58:25 UTC (rev 19599)
@@ -41,18 +41,6 @@
ClassLoader getClassLoader();
/**
- * Get the deployment type
- * @return deployment type
- */
- DeploymentType getType();
-
- /**
- * Set the deployment type
- * @param type deployment type
- */
- void setType(DeploymentType type);
-
- /**
* Get the service associated with this deployment
* @return service for the deployment
*/
9 years, 9 months
JBossWS SVN: r19598 - common/trunk/src/main/java/org/jboss/ws/common/deployment.
by jbossws-commits@lists.jboss.org
Author: rsearls
Date: 2015-03-23 14:41:32 -0400 (Mon, 23 Mar 2015)
New Revision: 19598
Modified:
common/trunk/src/main/java/org/jboss/ws/common/deployment/ArchiveDeploymentImpl.java
common/trunk/src/main/java/org/jboss/ws/common/deployment/DefaultDeployment.java
Log:
[JBWS-3878] implemented changes required by org.jboss.wsf.spi.deployment.Deployment.
Modified: common/trunk/src/main/java/org/jboss/ws/common/deployment/ArchiveDeploymentImpl.java
===================================================================
--- common/trunk/src/main/java/org/jboss/ws/common/deployment/ArchiveDeploymentImpl.java 2015-03-23 16:39:40 UTC (rev 19597)
+++ common/trunk/src/main/java/org/jboss/ws/common/deployment/ArchiveDeploymentImpl.java 2015-03-23 18:41:32 UTC (rev 19598)
@@ -28,6 +28,7 @@
import org.jboss.wsf.spi.deployment.ArchiveDeployment;
import org.jboss.wsf.spi.deployment.ResourceResolver;
import org.jboss.wsf.spi.deployment.UnifiedVirtualFile;
+import org.jboss.wsf.spi.deployment.DeploymentType;
/**
* A general web service deployment that is based on an archive.
@@ -44,6 +45,7 @@
private final UnifiedVirtualFile rootFile;
private List<UnifiedVirtualFile> metadataFiles;
+ private DeploymentType deploymentType;
ArchiveDeploymentImpl(String simpleName, ClassLoader classLoader, UnifiedVirtualFile rootFile)
{
@@ -98,4 +100,12 @@
{
return new ResourceResolverImpl(this);
}
+
+ public void setType(DeploymentType deploymentType) {
+ this.deploymentType = deploymentType;
+ }
+
+ public DeploymentType getType() {
+ return deploymentType;
+ }
}
Modified: common/trunk/src/main/java/org/jboss/ws/common/deployment/DefaultDeployment.java
===================================================================
--- common/trunk/src/main/java/org/jboss/ws/common/deployment/DefaultDeployment.java 2015-03-23 16:39:40 UTC (rev 19597)
+++ common/trunk/src/main/java/org/jboss/ws/common/deployment/DefaultDeployment.java 2015-03-23 18:41:32 UTC (rev 19598)
@@ -24,6 +24,7 @@
import org.jboss.wsf.spi.deployment.AbstractExtensible;
import org.jboss.wsf.spi.deployment.Deployment;
import org.jboss.wsf.spi.deployment.Service;
+import org.jboss.wsf.spi.deployment.DeploymentType;
/**
* A general web service deployment dep.
@@ -41,6 +42,7 @@
private final Service service;
// The runtime class loader
private final ClassLoader classLoader;
+ private DeploymentType deploymentType;
DefaultDeployment(String name, ClassLoader classLoader)
{
@@ -64,4 +66,12 @@
{
return service;
}
+
+ public void setType(DeploymentType deploymentType) {
+ this.deploymentType = deploymentType;
+ }
+
+ public DeploymentType getType() {
+ return deploymentType;
+ }
}
9 years, 9 months
JBossWS SVN: r19597 - in api/trunk: src/main/java/org/jboss/ws/api and 6 other directories.
by jbossws-commits@lists.jboss.org
Author: rsearls
Date: 2015-03-23 12:39:40 -0400 (Mon, 23 Mar 2015)
New Revision: 19597
Modified:
api/trunk/pom.xml
api/trunk/src/main/java/org/jboss/ws/api/Log.java
api/trunk/src/main/java/org/jboss/ws/api/Messages.java
api/trunk/src/main/java/org/jboss/ws/api/addressing/MAPBuilder.java
api/trunk/src/main/java/org/jboss/ws/api/annotation/EndpointConfig.java
api/trunk/src/main/java/org/jboss/ws/api/annotation/PolicySets.java
api/trunk/src/main/java/org/jboss/ws/api/annotation/WebContext.java
api/trunk/src/main/java/org/jboss/ws/api/configuration/AbstractClientFeature.java
api/trunk/src/main/java/org/jboss/ws/api/monitoring/Record.java
api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordFilter.java
api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordProcessor.java
api/trunk/src/main/java/org/jboss/ws/api/tools/WSContractProvider.java
api/trunk/src/main/java/org/jboss/ws/api/util/DOMUtils.java
Log:
"[JBWS-3878] resolve javaDoc warnings for jdk8 and 7"
Modified: api/trunk/pom.xml
===================================================================
--- api/trunk/pom.xml 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/pom.xml 2015-03-23 16:39:40 UTC (rev 19597)
@@ -27,6 +27,7 @@
<jboss-logging.version>3.1.2.GA</jboss-logging.version>
<jboss-logging-processor.version>1.0.3.Final</jboss-logging-processor.version>
<junit.version>3.8.2</junit.version>
+ <jboss-logging-annotations.version>1.2.0.Final</jboss-logging-annotations.version>
</properties>
<!-- Dependencies -->
@@ -45,8 +46,13 @@
<version>${jboss-logging-processor.version}</version>
<scope>provided</scope>
</dependency>
+ <dependency>
+ <groupId>org.jboss.logging</groupId>
+ <artifactId>jboss-logging-annotations</artifactId>
+ <version>${jboss-logging-annotations.version}</version>
+ <scope>provided</scope>
+ </dependency>
-
<!-- test dependencies -->
<dependency>
<groupId>junit</groupId>
Modified: api/trunk/src/main/java/org/jboss/ws/api/Log.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/Log.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/Log.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -26,9 +26,9 @@
import static org.jboss.logging.Logger.Level.WARN;
import org.jboss.logging.BasicLogger;
-import org.jboss.logging.LogMessage;
-import org.jboss.logging.Message;
-import org.jboss.logging.MessageLogger;
+import org.jboss.logging.annotations.LogMessage;
+import org.jboss.logging.annotations.Message;
+import org.jboss.logging.annotations.MessageLogger;
/**
* JBossWS API log messages
Modified: api/trunk/src/main/java/org/jboss/ws/api/Messages.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/Messages.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/Messages.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -21,9 +21,9 @@
*/
package org.jboss.ws.api;
-import org.jboss.logging.Cause;
-import org.jboss.logging.Message;
-import org.jboss.logging.MessageBundle;
+import org.jboss.logging.annotations.Cause;
+import org.jboss.logging.annotations.Message;
+import org.jboss.logging.annotations.MessageBundle;
/**
* JBossWS API exception messages
Modified: api/trunk/src/main/java/org/jboss/ws/api/addressing/MAPBuilder.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/addressing/MAPBuilder.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/addressing/MAPBuilder.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -66,14 +66,17 @@
/**
* Creates a new {@link org.jboss.ws.api.addressing.MAPEndpoint} instance
- *
+ *
+ * @param address endpoint address
* @return a {@link org.jboss.ws.api.addressing.MAPEndpoint} instance
*/
public MAPEndpoint newEndpoint(String address);
/**
* Creates a new {@link org.jboss.ws.api.addressing.MAPRelatesTo} instance
- *
+ *
+ * @param id identifier
+ * @param type Qname
* @return a {@link org.jboss.ws.api.addressing.MAPRelatesTo} instance
*/
public MAPRelatesTo newRelatesTo(String id, QName type);
Modified: api/trunk/src/main/java/org/jboss/ws/api/annotation/EndpointConfig.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/annotation/EndpointConfig.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/annotation/EndpointConfig.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -39,6 +39,8 @@
/**
* The configName gives the configuration name that must be present in the configuration given by configFile.
* If configName is not specified, the standard endpoint configuration is used.
+ *
+ * @return string
*/
String configName() default "";
@@ -46,6 +48,7 @@
* The configFile element is a URL or resource name for the configuration.
* The default value references the current AS configuration.
*
+ * @return string
*/
String configFile() default "";
}
Modified: api/trunk/src/main/java/org/jboss/ws/api/annotation/PolicySets.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/annotation/PolicySets.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/annotation/PolicySets.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -39,7 +39,8 @@
/**
* The names of the policy sets to be applied
- *
+ *
+ * @return string
*/
String[] value();
}
Modified: api/trunk/src/main/java/org/jboss/ws/api/annotation/WebContext.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/annotation/WebContext.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/annotation/WebContext.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -40,7 +40,9 @@
* The contextRoot element specifies the context root that the web service endpoint is deployed to.
* If it is not specified it will be derived from the deployment short name.
*
- * Applies to server side port components only.
+ * Applies to server side port components only
+ *
+ * @return string
*/
String contextRoot() default "";
@@ -48,6 +50,8 @@
* The virtual host that the web service endpoint is deployed to.
*
* Applies to server side port components only.
+ *
+ * @return string
*/
String virtualHost() default "";
@@ -55,7 +59,9 @@
* Relative path that is appended to the contextRoot to form fully qualified
* endpoint address for the web service endpoint.
*
- * Applies to server side port components only.
+ * Applies to server side port components only.
+ *
+ * @return string
*/
String urlPattern() default "";
@@ -68,6 +74,8 @@
* be specified.
*
* @see AuthMethod
+ *
+ * @return string
*/
String authMethod() default "";
@@ -84,6 +92,8 @@
* CONFIDENTIAL flag will indicate that the use of SSL is required.
*
* @see TransportGuarantee
+ *
+ * @return string
*/
String transportGuarantee() default "";
@@ -91,12 +101,16 @@
* A secure endpoint does not secure wsdl access by default.
* Explicitly setting secureWSDLAccess overrides this behaviour.
*
- * Protect access to WSDL. See http://jira.jboss.org/jira/browse/JBWS-723
+ * Protect access to WSDL. See http://jira.jboss.org/jira/browse/JBWS-723
+ *
+ * @return boolean
*/
boolean secureWSDLAccess() default false;
/**
* Description of the resource being accessed
+ *
+ * @return string
*/
String realmName() default "";
Modified: api/trunk/src/main/java/org/jboss/ws/api/configuration/AbstractClientFeature.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/configuration/AbstractClientFeature.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/configuration/AbstractClientFeature.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -42,7 +42,7 @@
* Initializes the provided JAXWS client component; this is called by the
* the JBossWS impl of JAXWS Provider.
*
- * @param obj
+ * @param obj client component
*/
public void initialize(Object obj)
{
@@ -55,7 +55,7 @@
/**
* Initializes the provided BindingProvider instance
*
- * @param bp
+ * @param bp binding provider
*/
protected void initializeBindingProvider(BindingProvider bp)
{
Modified: api/trunk/src/main/java/org/jboss/ws/api/monitoring/Record.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/monitoring/Record.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/monitoring/Record.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -54,7 +54,7 @@
/**
* Sets the groupID
*
- * @param groupID
+ * @param groupID id
*/
public void setGroupID(String groupID);
@@ -68,7 +68,7 @@
/**
* Sets the date of the record
*
- * @param date
+ * @param date date
*/
public void setDate(Date date);
@@ -82,7 +82,7 @@
/**
* Sets the source host
*
- * @param host
+ * @param host source host
*/
public void setSourceHost(String host);
@@ -96,7 +96,7 @@
/**
* Sets the destination host
*
- * @param host
+ * @param host destination host
*/
public void setDestinationHost(String host);
@@ -110,7 +110,7 @@
/**
* Sets the message type
*
- * @param type
+ * @param type message type
*/
public void setMessageType(MessageType type);
@@ -125,7 +125,7 @@
/**
* Sets the SOAP message envelope
*
- * @param envelope
+ * @param envelope SOAP message envelope
*/
public void setEnvelope(String envelope);
@@ -139,15 +139,15 @@
/**
* Adds a HTTP header to the record
*
- * @param key
- * @param value
+ * @param key id
+ * @param value value
*/
public void addHeaders(String key, List<String> value);
/**
* Sets the HTTP headers of the record
*
- * @param headers
+ * @param headers HTTP headers
*/
public void setHeaders(Map<String, List<String>> headers);
@@ -161,7 +161,7 @@
/**
* Sets the record's operation
*
- * @param operation
+ * @param operation record operation
*/
public void setOperation(QName operation);
}
Modified: api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordFilter.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordFilter.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordFilter.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -33,11 +33,17 @@
{
/**
* Returns true if the filter matches the given record.
+ *
+ * @param record record
+ * @return true success
*/
boolean match(Record record);
/**
* RecordFilters must override Object.clone()
+ *
+ * @return Object recode filter
+ * @throws CloneNotSupportedException exception
*/
Object clone() throws CloneNotSupportedException;
}
Modified: api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordProcessor.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordProcessor.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/monitoring/RecordProcessor.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -190,6 +190,9 @@
/**
* RecordFilters must override Object.clone()
+ *
+ * @return object
+ * @throws CloneNotSupportedException exception
*/
Object clone() throws CloneNotSupportedException;
}
Modified: api/trunk/src/main/java/org/jboss/ws/api/tools/WSContractProvider.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/tools/WSContractProvider.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/tools/WSContractProvider.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -142,7 +142,7 @@
* Sets the soap:address to be used for the generated port in the wsdl.
* This is ignored if WSDL generation is disabled.
*
- * @param address
+ * @param address soap address
*/
public abstract void setPortSoapAddress(String address);
Modified: api/trunk/src/main/java/org/jboss/ws/api/util/DOMUtils.java
===================================================================
--- api/trunk/src/main/java/org/jboss/ws/api/util/DOMUtils.java 2015-03-23 15:38:24 UTC (rev 19596)
+++ api/trunk/src/main/java/org/jboss/ws/api/util/DOMUtils.java 2015-03-23 16:39:40 UTC (rev 19597)
@@ -65,7 +65,11 @@
*/
public abstract class DOMUtils
{
- /** Get the qname of the given node.
+ /**
+ * Get the qname of the given node.
+ *
+ * @param el node
+ * @return Qname
*/
public static QName getElementQName(Element el)
{
@@ -74,6 +78,10 @@
}
/** Transform the given qualified name into a QName
+ *
+ * @param el node
+ * @param qualifiedName qualified name
+ * @return QName
*/
public static QName resolveQName(Element el, String qualifiedName)
{
@@ -128,6 +136,8 @@
/** Get the value from the given attribute
*
+ * @param el element
+ * @param attrName attribute name
* @return null if the attribute value is empty or the attribute is not present
*/
public static String getAttributeValue(Element el, String attrName)
@@ -137,6 +147,8 @@
/** Get the value from the given attribute
*
+ * @param el element
+ * @param attrName attribute name
* @return null if the attribute value is empty or the attribute is not present
*/
public static String getAttributeValue(Element el, QName attrName)
@@ -153,7 +165,12 @@
return attr;
}
- /** Get the qname value from the given attribute
+ /**
+ * Get the qname value from the given attribute
+ *
+ * @param el element
+ * @param attrName attribute name
+ * @return QName
*/
public static QName getAttributeValueAsQName(Element el, String attrName)
{
@@ -161,7 +178,12 @@
}
- /** Get the qname value from the given attribute
+ /**
+ * Get the qname value from the given attribute
+ *
+ * @param el element
+ * @param attrName attribute name
+ * @return QName
*/
public static QName getAttributeValueAsQName(Element el, QName attrName)
{
@@ -176,14 +198,24 @@
return qname;
}
- /** Get the boolean value from the given attribute
+ /**
+ * Get the boolean value from the given attribute
+ *
+ * @param el element
+ * @param attrName attribute name
+ * @return boolean
*/
public static boolean getAttributeValueAsBoolean(Element el, String attrName)
{
return getAttributeValueAsBoolean(el, new QName(attrName));
}
- /** Get the boolean value from the given attribute
+ /**
+ * Get the boolean value from the given attribute
+ *
+ * @param el element
+ * @param attrName attribute name
+ * @return boolean
*/
public static boolean getAttributeValueAsBoolean(Element el, QName attrName)
{
@@ -192,14 +224,24 @@
return ret;
}
- /** Get the integer value from the given attribute
+ /**
+ * Get the integer value from the given attribute
+ *
+ * @param el element
+ * @param attrName attribute name
+ * @return Integer
*/
public static Integer getAttributeValueAsInteger(Element el, String attrName)
{
return getAttributeValueAsInteger(el, new QName(attrName));
}
- /** Get the integer value from the given attribute
+ /**
+ * Get the integer value from the given attribute
+ *
+ * @param el element
+ * @param attrName attribute name
+ * @return Integer
*/
public static Integer getAttributeValueAsInteger(Element el, QName attrName)
{
@@ -207,7 +249,11 @@
return (attrVal != null ? new Integer(attrVal) : null);
}
- /** Get the attributes as Map<QName, String>
+ /**
+ * Get the attributes as Map<QName, String>
+ *
+ * @param el element
+ * @return Map
*/
public static Map<QName, String> getAttributes(Element el)
{
@@ -225,7 +271,11 @@
return attmap;
}
- /** Copy attributes between elements
+ /**
+ * Copy attributes between elements
+ *
+ * @param destElement element
+ * @param srcElement element
*/
public static void copyAttributes(Element destElement, Element srcElement)
{
@@ -252,7 +302,11 @@
}
}
- /** True if the node has text child elements only
+ /**
+ * True if the node has text child elements only
+ *
+ * @param node start node
+ * @return True if the node has text child
*/
public static boolean hasTextChildNodesOnly(Node node)
{
@@ -271,7 +325,11 @@
return true;
}
- /** True if the node has child elements
+ /**
+ * True if the node has child elements
+ *
+ * @param node start node
+ * @return true when child has elements
*/
public static boolean hasChildElements(Node node)
{
@@ -286,7 +344,11 @@
return false;
}
- /** Gets child elements
+ /**
+ * Gets child elements
+ *
+ * @param node start node
+ * @return Iterator
*/
public static Iterator<Element> getChildElements(Node node)
{
@@ -302,7 +364,11 @@
return list.iterator();
}
- /** Get the concatenated text content, or null.
+ /**
+ * Get the concatenated text content, or null.
+ *
+ * @param node node
+ * @return string
*/
public static String getTextContent(Node node)
{
@@ -322,14 +388,23 @@
return (hasTextContent ? buffer.toString() : null);
}
- /** Gets the first child element
+ /**
+ * Gets the first child element
+ *
+ * @param node start node
+ * @return element
*/
public static Element getFirstChildElement(Node node)
{
return getFirstChildElement(node, false);
}
- /** Gets the first child element
+ /**
+ * Gets the first child element
+ *
+ * @param node child
+ * @param recursive recurse flag
+ * @return element
*/
public static Element getFirstChildElement(Node node, boolean recursive)
{
@@ -337,27 +412,48 @@
}
/** Gets the first child element for a given local name without namespace
+ *
+ * @param node child
+ * @param nodeName name
+ * @return element
*/
public static Element getFirstChildElement(Node node, String nodeName)
{
return getFirstChildElement(node, nodeName, false);
}
- /** Gets the first child element for a given local name without namespace
+ /**
+ * Gets the first child element for a given local name without namespace
+ *
+ * @param node child
+ * @param nodeName name
+ * @param recursive recurse flag
+ * @return element
*/
public static Element getFirstChildElement(Node node, String nodeName, boolean recursive)
{
return getFirstChildElementIntern(node, new QName(nodeName), recursive);
}
- /** Gets the first child element for a given qname
+ /**
+ * Gets the first child element for a given qname
+ *
+ * @param node child
+ * @param nodeName name
+ * @return element
*/
public static Element getFirstChildElement(Node node, QName nodeName)
{
return getFirstChildElement(node, nodeName, false);
}
- /** Gets the first child element for a given qname
+ /**
+ * Gets the first child element for a given qname
+ *
+ * @param node child
+ * @param nodeName name
+ * @param recursive recurse flag
+ * @return element
*/
public static Element getFirstChildElement(Node node, QName nodeName, boolean recursive)
{
@@ -375,28 +471,50 @@
return childElement;
}
- /** Gets the child elements for a given local name without namespace
+ /**
+ * Gets the child elements for a given local name without namespace
+ *
+ * @param node child
+ * @param nodeName name
+ * @return Iterator
*/
public static Iterator<Element> getChildElements(Node node, String nodeName)
{
return getChildElements(node, nodeName, false);
}
- /** Gets the child elements for a given local name without namespace
+ /**
+ * Gets the child elements for a given local name without namespace
+ *
+ * @param node child
+ * @param nodeName name
+ * @param recursive recurse flag
+ * @return Iterator
*/
public static Iterator<Element> getChildElements(Node node, String nodeName, boolean recursive)
{
return getChildElementsIntern(node, new QName(nodeName), recursive);
}
- /** Gets the child element for a given qname
+ /**
+ * Gets the child element for a given qname
+ *
+ * @param node child
+ * @param nodeName name
+ * @return Iterator
*/
public static Iterator<Element> getChildElements(Node node, QName nodeName)
{
return getChildElements(node, nodeName, false);
}
- /** Gets the child element for a given qname
+ /**
+ * Gets the child element for a given qname
+ *
+ * @param node child
+ * @param nodeName name
+ * @param recursive recurse flag
+ * @return Iterator
*/
public static Iterator<Element> getChildElements(Node node, QName nodeName, boolean recursive)
{
@@ -482,7 +600,11 @@
return getChildElementsAsListIntern(node, nodeName, recursive).iterator();
}
- /** Gets parent element or null if there is none
+ /**
+ * Gets parent element or null if there is none
+ *
+ * @param node child
+ * @return element
*/
public static Element getParentElement(Node node)
{
@@ -557,7 +679,13 @@
return retElement;
}
- /** Parse the given XML string and return the root Element
+ /**
+ * Parse the given XML string and return the root Element
+ *
+ * @param xmlString string to be parsed
+ * @param builder document builder
+ * @return element
+ * @throws IOException exception
*/
public static Element parse(String xmlString, DocumentBuilder builder) throws IOException
{
@@ -572,7 +700,13 @@
}
}
- /** Parse the given XML stream and return the root Element
+ /**
+ * Parse the given XML stream and return the root Element
+ *
+ * @param xmlStream input stream
+ * @param builder document builder
+ * @return element
+ * @throws IOException exception
*/
public static Element parse(InputStream xmlStream, DocumentBuilder builder) throws IOException
{
@@ -595,7 +729,13 @@
}
}
- /** Parse the given input source and return the root Element
+ /**
+ * Parse the given input source and return the root Element
+ *
+ * @param source input source
+ * @param builder document builder
+ * @return element
+ * @throws IOException exception
*/
public static Element parse(InputSource source, DocumentBuilder builder) throws IOException
{
@@ -627,7 +767,14 @@
}
}
- /** Create an Element for a given name, prefix and uri
+ /**
+ * Create an Element for a given name, prefix and uri
+ *
+ * @param localPart xml local part
+ * @param prefix xml prefix
+ * @param uri uri
+ * @param doc document
+ * @return element
*/
public static Element createElement(String localPart, String prefix, String uri, Document doc)
{
9 years, 9 months
JBossWS SVN: r19596 - in spi/trunk: src/main/java/org/jboss/wsf/spi and 9 other directories.
by jbossws-commits@lists.jboss.org
Author: rsearls
Date: 2015-03-23 11:38:24 -0400 (Mon, 23 Mar 2015)
New Revision: 19596
Modified:
spi/trunk/pom.xml
spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProvider.java
spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProviderResolver.java
spi/trunk/src/main/java/org/jboss/wsf/spi/classloading/ClassLoaderProvider.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ArchiveDeployment.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/DeploymentAspectManager.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/EndpointType.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Extensible.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/HttpEndpoint.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/LifecycleHandler.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ResourceResolver.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/UnifiedVirtualFile.java
spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/WSFServlet.java
spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/HandlerCallback.java
spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/InvocationHandler.java
spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/RequestHandler.java
spi/trunk/src/main/java/org/jboss/wsf/spi/management/CommonConfigStore.java
spi/trunk/src/main/java/org/jboss/wsf/spi/management/EndpointRegistry.java
spi/trunk/src/main/java/org/jboss/wsf/spi/management/ServerConfig.java
spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/DescriptorParser.java
spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/j2ee/serviceref/UnifiedPortComponentRefMetaData.java
spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/webservices/WebserviceDescriptionMetaData.java
spi/trunk/src/main/java/org/jboss/wsf/spi/security/SecurityDomainContext.java
spi/trunk/src/main/java/org/jboss/wsf/spi/util/StAXUtils.java
Log:
"[JBWS-3878] resolve javaDoc warnings for jdk8 and 7"
Modified: spi/trunk/pom.xml
===================================================================
--- spi/trunk/pom.xml 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/pom.xml 2015-03-23 15:38:24 UTC (rev 19596)
@@ -31,6 +31,7 @@
<jboss-logging-processor.version>1.0.3.Final</jboss-logging-processor.version>
<servlet.api.version>1.0.2.Final</servlet.api.version>
<junit.version>3.8.2</junit.version>
+ <jboss-logging-annotations.version>1.2.0.Final</jboss-logging-annotations.version>
</properties>
<!-- Dependencies -->
@@ -67,6 +68,11 @@
<version>${jboss-logging-processor.version}</version>
<scope>provided</scope>
</dependency>
+ <dependency>
+ <groupId>org.jboss.logging</groupId>
+ <artifactId>jboss-logging-annotations</artifactId>
+ <version>${jboss-logging-annotations.version}</version>
+ </dependency>
<!-- test dependencies -->
<dependency>
@@ -77,6 +83,20 @@
</dependency>
</dependencies>
+ <!-- Disable javadoc warnings in jdk 1.8. jdk 1.7 does not support this -->
+ <!-- rls
+ <profiles>
+ <profile>
+ <id>doclint-java8-disable</id>
+ <activation>
+ <jdk>[1.8,)</jdk>
+ </activation>
+ <properties>
+ <javadoc.opts>-Xdoclint:none</javadoc.opts>
+ </properties>
+ </profile>
+ </profiles>
+ -->
<!-- Plugins -->
<build>
<plugins>
@@ -92,13 +112,23 @@
<plugin>
<groupId>org.apache.maven.plugins</groupId>
<artifactId>maven-javadoc-plugin</artifactId>
- <version>2.8</version>
+ <version>2.9.1</version> <!-- 2.8 rls -->
<executions>
<execution>
<phase>package</phase>
<goals>
<goal>jar</goal>
</goals>
+ <!-- ${javadoc.opts} -->
+ <!--
+ <configuration>
+ <additionalparam>-Xdoclint:none</additionalparam>
+ </configuration>
+
+ <configuration>
+ <failOnError>false</failOnError>
+ </configuration>
+ -->
</execution>
</executions>
</plugin>
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProvider.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProvider.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProvider.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -37,7 +37,7 @@
* Gets the a singleton reference to the SPIProvider returned by the SPIProviderResolver
* retrieved using the default server integration classloader.
*
- * @return
+ * @return this class instance
*/
public static SPIProvider getInstance()
{
@@ -52,9 +52,9 @@
/**
* Gets the specified SPI, using the current thread context classloader
*
- * @param <T>
- * @param spiType
- * @return
+ * @param <T> type of spi class
+ * @param spiType spi class to retrieve
+ * @return object
*/
public <T> T getSPI(Class<T> spiType)
{
@@ -64,10 +64,10 @@
/**
* Gets the specified SPI, using the provided classloader
*
- * @param <T>
- * @param spiType
- * @param loader
- * @return
+ * @param <T> type of spi class
+ * @param spiType spi class to retrieve
+ * @param loader classloader to user
+ * @return object
*/
public abstract <T> T getSPI(Class<T> spiType, ClassLoader loader);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProviderResolver.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProviderResolver.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/SPIProviderResolver.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -36,7 +36,7 @@
/**
* Get the SPIProviderResolver instance using the thread context classloader for lookup
*
- * @return
+ * @return instance of this class
*/
public static SPIProviderResolver getInstance()
{
@@ -45,8 +45,9 @@
/**
* Get the SPIProviderResolver instance using the provided classloader for lookup
- *
- * @return
+ *
+ * @param cl classloader to use for lookup
+ * @return instance of this class
*/
public static SPIProviderResolver getInstance(ClassLoader cl)
{
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/classloading/ClassLoaderProvider.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/classloading/ClassLoaderProvider.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/classloading/ClassLoaderProvider.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -78,21 +78,21 @@
/**
* Return the ClassLoader instance having visibility over the application server ws subsystem only
*
- * @return
+ * @return classloader
*/
public abstract ClassLoader getWebServiceSubsystemClassLoader();
/**
* Return the ClassLoader instance having visibility over the all server side ws libraries (for JAXWS usage)
*
- * @return
+ * @return classloader
*/
public abstract ClassLoader getServerIntegrationClassLoader();
/**
* Return the ClassLoader instance having visibility over the all server side ws libraries (for JAXRPC usage)
*
- * @return
+ * @return classloader
*/
public abstract ClassLoader getServerJAXRPCIntegrationClassLoader();
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ArchiveDeployment.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ArchiveDeployment.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ArchiveDeployment.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -31,22 +31,40 @@
*/
public interface ArchiveDeployment extends Deployment
{
- /** Get the optional parent of this deployment */
+ /**
+ * Get the optional parent of this deployment
+ * @return parent of the deployment
+ */
ArchiveDeployment getParent();
- /** Get the root file for this deployment */
+ /**
+ * Get the root file for this deployment
+ * @return root file of the deployment
+ */
UnifiedVirtualFile getRootFile();
-
- /** The concatenated names including all parents. */
+
+ /**
+ * The concatenated names including all parents.
+ * @return concatenated names
+ */
String getCanonicalName();
-
- /** Get additional metadata files attached to the deployment **/
+
+ /**
+ * Get additional metadata files attached to the deployment
+ * @return metadata files attached to the deployment
+ */
List<UnifiedVirtualFile> getMetadataFiles();
-
- /** Add additional metadata file to the deployment **/
+
+ /**
+ * Add additional metadata file to the deployment
+ * @param file metadata file to the deployment
+ */
void addMetadataFile(UnifiedVirtualFile file);
-
- /** Get the resource resolver to be used to access resources from this archive */
+
+ /**
+ * Get the resource resolver to be used to access resources from this archive
+ * @return resource resolver
+ */
ResourceResolver getResourceResolver();
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/DeploymentAspectManager.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/DeploymentAspectManager.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -32,18 +32,33 @@
*/
public interface DeploymentAspectManager
{
- /** Get the name for this aspect manager */
+ /**
+ * Get the name for this aspect manager
+ * @return name of aspect manager
+ */
String getName();
-
- /** Get the list of registered deployment aspects */
+
+ /**
+ * Get the list of registered deployment aspects
+ * @return list of registered deployment aspects
+ */
List<DeploymentAspect> getDeploymentAspects();
-
- /** Set the list of registered deployment aspects */
+
+ /**
+ * Set the list of registered deployment aspects
+ * @param aspects set of registered deployment aspects
+ */
void setDeploymentAspects(List<DeploymentAspect> aspects);
- /** Deploy a web service */
+ /**
+ * Deploy a web service
+ * @param dep web service to deploy
+ */
void deploy(Deployment dep);
- /** Undeploy a web service */
+ /**
+ * Undeploy a web service
+ * @param dep web service deployment
+ */
void undeploy(Deployment dep);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Endpoint.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -48,99 +48,226 @@
static final String SEPID_DOMAIN_ENDPOINT = SEPID_DOMAIN + "." + SEPID_PROPERTY_ENDPOINT;
- /** Get the service this endpoint belongs to */
+ /**
+ * Get the service this endpoint belongs to
+ *
+ * @return endpoint service
+ */
Service getService();
- /** Set the service this endpoint belongs to */
+ /**
+ * Set the service this endpoint belongs to
+ *
+ * @param service endpoint service
+ */
void setService(Service service);
- /** Get the unique identifier for this endpoint */
+ /**
+ * Get the unique identifier for this endpoint
+ *
+ * @return endpoint identifier
+ */
ObjectName getName();
- /** Set the unique identifier for this endpoint */
+ /**
+ * Set the unique identifier for this endpoint
+ *
+ * @param epName endpoint identifier
+ */
void setName(ObjectName epName);
- /** Get the short name for this endpoint */
+ /**
+ * Get the short name for this endpoint
+ *
+ * @return endpoint short name
+ */
String getShortName();
- /** Set the short name for this endpoint */
+ /**
+ * Set the short name for this endpoint
+ *
+ * @param shortName endpoint short name
+ */
void setShortName(String shortName);
- /** Get the current state for this endpoint */
+ /**
+ * Get the current state for this endpoint
+ *
+ * @return endpoint state
+ */
EndpointState getState();
- /** Set the current state for this endpoint */
+ /**
+ * Set the current state for this endpoint
+ *
+ * @param state endpoint state
+ */
void setState(EndpointState state);
- /** Get endpoint type */
+ /**
+ * Get endpoint type
+ *
+ * @return endpoint type
+ */
EndpointType getType();
- /** Set endpoint type */
+ /**
+ * Set endpoint type
+ *
+ * @param type endpoint type
+ */
void setType(EndpointType type);
- /** Get the endpoint implementation bean */
+ /**
+ * Get the endpoint implementation bean
+ *
+ * @return name of endpoint bean
+ */
String getTargetBeanName();
- /** Set the endpoint implementation bean */
+ /**
+ * Set the endpoint implementation bean
+ *
+ * @param epImpl name of endpoint bean
+ */
void setTargetBeanName(String epImpl);
- /** Use the deployment classloader to load the bean */
+ /**
+ * Use the deployment classloader to load the bean
+ *
+ * @return bean loaded
+ */
Class<?> getTargetBeanClass();
- /** Set the request handler for this endpoint */
+ /**
+ * Set the request handler for this endpoint
+ *
+ * @param handler endpoint request handler
+ */
void setRequestHandler(RequestHandler handler);
- /** Get the request handler for this endpoint */
+ /**
+ * Get the request handler for this endpoint
+ *
+ * @return endpoint request handler
+ */
RequestHandler getRequestHandler();
- /** Get the lifecycle handler for this endpoint */
+ /**
+ * Get the lifecycle handler for this endpoint
+ *
+ * @return endpoint lifecycle handler
+ */
LifecycleHandler getLifecycleHandler();
- /** Set the lifecycle handler for this endpoint */
+ /**
+ * Set the lifecycle handler for this endpoint
+ *
+ * @param handler endpoint lifecycle handler
+ */
void setLifecycleHandler(LifecycleHandler handler);
- /** Get the endpoint bean invoker */
+ /**
+ * Get the endpoint bean invoker
+ *
+ * @return endpoint invoker
+ */
InvocationHandler getInvocationHandler();
- /** Set the endpoint bean invoker */
+ /**
+ * Set the endpoint bean invoker
+ *
+ * @param invoker endpoint invoker
+ */
void setInvocationHandler(InvocationHandler invoker);
- /** Get the endpoint metrics for this endpoint */
+ /**
+ * Get the endpoint metrics for this endpoint
+ *
+ * @return endpoint metrics
+ */
EndpointMetrics getEndpointMetrics();
- /** Set the endpoint metrics for this endpoint */
+ /**
+ * Set the endpoint metrics for this endpoint
+ *
+ * @param metrics endpoint metrics
+ */
void setEndpointMetrics(EndpointMetrics metrics);
- /** Get the record processors configured for this endpoint **/
+ /**
+ * Get the record processors configured for this endpoint
+ *
+ * @return set of endpoint record processors
+ */
List<RecordProcessor> getRecordProcessors();
- /** Set the record processors for this endpoint **/
+ /**
+ * Set the record processors for this endpoint
+ *
+ * @param recordProcessors set of endpoint record processors
+ */
void setRecordProcessors(List<RecordProcessor> recordProcessors);
- /** Ask configured processors for processing of the given record **/
+ /**
+ * Ask configured processors for processing of the given record
+ *
+ * @param record record to process
+ */
void processRecord(Record record);
- /** Get endpoint address */
+ /**
+ * Get endpoint address
+ *
+ * @return endpoint address
+ */
String getAddress();
- /** Set endpoint address */
+ /**
+ * Set endpoint address
+ *
+ * @param address endpoint address
+ */
void setAddress(String address);
- /** Get security domain context */
+ /**
+ * Get security domain context
+ *
+ * @return security domain context
+ */
SecurityDomainContext getSecurityDomainContext();
- /** Set security domain context */
+ /**
+ * Set security domain context
+ *
+ * @param context security domain context
+ */
void setSecurityDomainContext(SecurityDomainContext context);
- /** Get instance provider */
+ /**
+ * Get instance provider
+ *
+ * @return instance provider
+ */
InstanceProvider getInstanceProvider();
- /** Set instance provider */
+ /**
+ * Set instance provider
+ *
+ * @param provider instance provider
+ */
void setInstanceProvider(InstanceProvider provider);
- /** Get endpoint config */
+ /**
+ * Get endpoint config
+ *
+ * @return endpoint config
+ */
EndpointConfig getEndpointConfig();
-
- /** Set endpoint config */
+
+ /**
+ * Set endpoint config
+ * @param config endpoint config
+ */
void setEndpointConfig(EndpointConfig config);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/EndpointType.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/EndpointType.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/EndpointType.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -1,6 +1,6 @@
/*
* JBoss, Home of Professional Open Source.
- * Copyright 2014, Red Hat, Inc., and individual contributors
+ * Copyright 2011, Red Hat, Inc., and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
@@ -29,5 +29,5 @@
*/
public enum EndpointType
{
- JAXWS_JSE, JAXWS_EJB3
+ JAXRPC_JSE, JAXRPC_EJB21, JAXWS_JSE, JAXWS_EJB3
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Extensible.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Extensible.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Extensible.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -33,30 +33,72 @@
*/
public interface Extensible
{
- /** Add arbitrary attachments */
+
+ /**
+ * Add arbitrary attachments
+ *
+ * @param key identifier
+ * @param value value
+ * @param <T> class type
+ * @return added attachment
+ */
<T> T addAttachment(Class<T> key, Object value);
-
- /** Get arbitrary attachments */
+
+ /**
+ * Get arbitrary attachments
+ *
+ * @param <T> class type of attachments
+ * @return collection of attachments
+ */
<T> Collection<T> getAttachments();
-
- /** Get an arbitrary attachment */
+
+ /**
+ * Get an arbitrary attachment
+ *
+ * @param key identifier
+ * @param <T> class type of attachments
+ * @return attachment found
+ */
<T> T getAttachment(Class<T> key);
-
- /** Remove arbitrary attachments */
+
+ /**
+ * Remove arbitrary attachments
+ * @param key identifier
+ * @param <T> class type of attachments
+ * @return attachment removed
+ */
<T> T removeAttachment(Class<T> key);
- /** Get an property */
+ /**
+ * Get an property
+ *
+ * @param key property identifier
+ * @return found property
+ */
Object getProperty(String key);
-
- /** Set a property */
+
+ /**
+ * Set a property
+ * @param key property identifier
+ * @param value property value
+ */
void setProperty(String key, Object value);
-
- /** Remove a property */
+
+ /**
+ * Remove a property
+ * @param key property identifier
+ */
void removeProperty(String key);
-
- /** Get the set of property names */
+
+ /**
+ * Get the set of property names
+ * @return set of property values
+ */
Set<String> getProperties();
-
- /** Set a map of properties */
+
+ /**
+ * Set a map of properties
+ * @param props map to retain
+ */
void setProperties(Map<String, Object> props);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/HttpEndpoint.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/HttpEndpoint.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/HttpEndpoint.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -28,9 +28,17 @@
*/
public interface HttpEndpoint extends Endpoint
{
- /** Get the URL pattern for this endpoint */
+ /**
+ * Get the URL pattern for this endpoint
+ *
+ * @return endpoint URL pattern
+ */
String getURLPattern();
- /** Set the URL pattern for this endpoint */
+ /**
+ * Set the URL pattern for this endpoint
+ *
+ * @param urlPattern endpoint URL pattern
+ */
void setURLPattern(String urlPattern);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/LifecycleHandler.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/LifecycleHandler.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/LifecycleHandler.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -29,9 +29,17 @@
*/
public interface LifecycleHandler
{
- /** Handle the start step of an endpoint */
+ /**
+ * Handle the start step of an endpoint
+ *
+ * @param endpoint endpoint to start
+ */
void start(Endpoint endpoint);
- /** Handle the stop step of an endpoint */
+ /**
+ * Handle the stop step of an endpoint
+ *
+ * @param endpoint endpoint to stop
+ */
void stop(Endpoint endpoint);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ResourceResolver.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ResourceResolver.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/ResourceResolver.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -33,11 +33,12 @@
*/
public interface ResourceResolver
{
- /** Get the URL for a given resource path
+ /**
+ * Get the URL for a given resource path
*
- * @param resourcePath
- * @return
- * @throws IOException
+ * @param resourcePath resource path
+ * @return URL of resource
+ * @throws IOException IO exception
*/
public URL resolve(String resourcePath) throws IOException;
@@ -45,8 +46,8 @@
* Same as resolve(String resourcePath) except it does not throw exception
* when resource is not found, simply returns null.
*
- * @param resourcePath
- * @return
+ * @param resourcePath resource path
+ * @return URL of resource
*/
public URL resolveFailSafe(String resourcePath);
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/UnifiedVirtualFile.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/UnifiedVirtualFile.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/UnifiedVirtualFile.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -40,8 +40,8 @@
* Same as findChild(String child) but does not throw any exception
* on child not found, simply returns null.
*
- * @param child
- * @return
+ * @param child name of child to find
+ * @return found child
*/
UnifiedVirtualFile findChildFailSafe(String child);
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/WSFServlet.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/WSFServlet.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/WSFServlet.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -66,7 +66,7 @@
* is used to lookup the factory
* - otherwise the current thread context classloader is used to lookup the factory.
*
- * @param servletConfig
+ * @param servletConfig servlet config
* @return the servlet delegate
*/
protected ServletDelegate getDelegate(ServletConfig servletConfig)
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/HandlerCallback.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/HandlerCallback.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/HandlerCallback.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -31,12 +31,31 @@
*/
public interface HandlerCallback
{
- /** Handlers are beeing called through the HandlerCallback from the EJB interceptor */
+ /**
+ * Handlers are being called through the HandlerCallback from the EJB interceptor
+ *
+ * @param wsInv invocation handler
+ * @param type handler
+ * @return true success
+ */
boolean callRequestHandlerChain(Invocation wsInv, HandlerType type);
- /** Handlers are beeing called through the HandlerCallback from the EJB interceptor */
+ /**
+ * Handlers are being called through the HandlerCallback from the EJB interceptor
+ *
+ * @param wsInv invocation handler
+ * @param type handler
+ * @return true success
+ */
boolean callResponseHandlerChain(Invocation wsInv, HandlerType type);
- /** Handlers are beeing called through the HandlerCallback from the EJB interceptor */
+ /**
+ * Handlers are being called through the HandlerCallback from the EJB interceptor
+ *
+ * @param wsInv invocation handler
+ * @param type handler
+ * @param ex exception
+ * @return true success
+ */
boolean callFaultHandlerChain(Invocation wsInv, HandlerType type, Exception ex);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/InvocationHandler.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/InvocationHandler.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/InvocationHandler.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -36,13 +36,27 @@
*/
public abstract class InvocationHandler
{
- /** Create a container specific invocation */
+ /**
+ * Create a container specific invocation
+ *
+ * @return invocation
+ */
public abstract Invocation createInvocation();
- /** Invoke the the service endpoint */
+ /**
+ * Invoke the the service endpoint
+ *
+ * @param ep endpoint
+ * @param inv invocation
+ * @throws Exception exception
+ */
public abstract void invoke(Endpoint ep, Invocation inv) throws Exception;
- /** Initilize the invocation handler */
+ /**
+ * Initilize the invocation handler
+ *
+ * @param ep endpoint
+ */
public abstract void init(Endpoint ep);
protected void handleInvocationException(Throwable th) throws Exception
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/RequestHandler.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/RequestHandler.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/invocation/RequestHandler.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -38,7 +38,15 @@
*/
public interface RequestHandler
{
- /** Handle a web service http request
+ /**
+ * Handle a web service http request
+ *
+ * @param endpoint endpoint
+ * @param req request
+ * @param res response
+ * @param context context
+ * @throws ServletException exception
+ * @throws IOException exception
*/
void handleHttpRequest(Endpoint endpoint, HttpServletRequest req, HttpServletResponse res, ServletContext context) throws ServletException, IOException;
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/management/CommonConfigStore.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/management/CommonConfigStore.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/management/CommonConfigStore.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -37,14 +37,14 @@
/**
* Registers a config in the store; the new config will affect runtime the first time the store is reloaded.
*
- * @param config
+ * @param config Registers a config in the store
*/
void register(T config);
/**
* Unregisters a config in the store; the runtime will be affected the first time the store is reloaded.
*
- * @param config
+ * @param config Unregisters a config in the store
*/
void unregister(T config);
@@ -62,7 +62,7 @@
/**
* Sets a wrapper config, to be merged with any registered config.
*
- * @param config
+ * @param config Sets a wrapper config
* @param reload Whether to reload the store after having set the wrapper or not
*/
void setWrapperConfig(T config, boolean reload);
@@ -70,22 +70,22 @@
/**
* Returns current wrapper config
*
- * @return
+ * @return Returns current wrapper config
*/
T getWrapperConfig();
/**
* Retrieves a config by name from the loaded collection
*
- * @param name
- * @return
+ * @param name Retrieves a config by name
+ * @return The matching config
*/
T getConfig(String name);
/**
* Returns the loaded config collection
*
- * @return
+ * @return the config collection
*/
Collection<T> getConfigs();
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/management/EndpointRegistry.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/management/EndpointRegistry.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/management/EndpointRegistry.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -37,15 +37,30 @@
*/
public interface EndpointRegistry
{
- /** Get the list of registered endpoints */
+ /**
+ * Get the list of registered endpoints
+ * @return list of registered endpoints
+ */
Set<ObjectName> getEndpoints();
- /** Get the registered endpoint */
+ /**
+ * Get the registered endpoint
+ * @param epName endpoint to return
+ * @return registered endpoint
+ */
Endpoint getEndpoint(ObjectName epName);
- /** Resolve endpoints thrrough a resolve instance **/
+ /**
+ * Resolve endpoints through a resolve instance
+ * @param resolver resolver endpoint
+ * @return found resolved endpoint
+ */
Endpoint resolve(EndpointResolver resolver);
- /** True is an endpoint for that name is registered */
+ /**
+ * True is an endpoint for that name is registered
+ * @param epName endpoint to lookup
+ * @return True if endpoint for name is registered
+ */
boolean isRegistered(ObjectName epName);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/management/ServerConfig.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/management/ServerConfig.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/management/ServerConfig.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -79,7 +79,7 @@
* Register a client config in the server configuration; the new config will apply to runtime when the server config is started
* or after a client config store reload.
*
- * @param config
+ * @param config client config to register
*/
void registerClientConfig(ClientConfig config);
@@ -87,7 +87,7 @@
* Unregister a client config from the server configuration; the new config will be removed from
* the collection returned to callers after next endpoint store reload.
*
- * @param config
+ * @param config client config to unregister
*/
void unregisterClientConfig(ClientConfig config);
@@ -98,8 +98,9 @@
/**
* Get a client config by name
- *
- * @return
+ *
+ * @param name name of client config
+ * @return named client config
*/
ClientConfig getClientConfig(String name);
@@ -107,7 +108,7 @@
* Register an endpoint config in the server configuration; the new config will apply to runtime when the server config is started
* or after an endpoint config store reload.
*
- * @param config
+ * @param config endpoint config to register
*/
void registerEndpointConfig(EndpointConfig config);
@@ -115,7 +116,7 @@
* Unregister an endpoint config from the server configuration; the new config will be removed from
* the collection returned to callers after next endpoint store reload.
*
- * @param config
+ * @param config endpoint config to unregister
*/
void unregisterEndpointConfig(EndpointConfig config);
@@ -126,8 +127,9 @@
/**
* Get an endpoint config by name
- *
- * @return
+ *
+ * @param name name of endpoint
+ * @return found named endpoint config
*/
EndpointConfig getEndpointConfig(String name);
/**
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/DescriptorParser.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/DescriptorParser.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/DescriptorParser.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -41,8 +41,8 @@
* Parses the descriptor at the provided URL and returns
* the corresponding object (metadata)
*
- * @param url
- * @return
+ * @param url url
+ * @return metadata
*/
T parse(final URL url);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/j2ee/serviceref/UnifiedPortComponentRefMetaData.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/j2ee/serviceref/UnifiedPortComponentRefMetaData.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/j2ee/serviceref/UnifiedPortComponentRefMetaData.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -148,6 +148,9 @@
* or another module in the same application unit. The syntax
* for specification follows the syntax defined for ejb-link
* in the EJB 2.0 specification.
+
+ *
+ * @return string
*/
public String getPortComponentLink()
{
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/webservices/WebserviceDescriptionMetaData.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/webservices/WebserviceDescriptionMetaData.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/metadata/webservices/WebserviceDescriptionMetaData.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -98,7 +98,7 @@
* Get the QNames of the port components to be declared
* in the namespaces
*
- * @return
+ * @return collection of QNames
*/
public Collection<QName> getPortComponentQNames()
{
@@ -164,7 +164,7 @@
/**
* Serialize as a String
*
- * @return
+ * @return string
*/
public String serialize()
{
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/security/SecurityDomainContext.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/security/SecurityDomainContext.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/security/SecurityDomainContext.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -72,7 +72,8 @@
/**
* Return the set of domain roles the principal has been assigned.
- *
+ *
+ * @param principal principal
* @return The <code>Set<java.security.Principal></code> for the application domain roles that the principal has been assigned.
*/
public Set<Principal> getUserRoles(Principal principal);
@@ -81,9 +82,9 @@
* Push the provided subject into the current security context; if that's not set yet,
* also creates a new security context and associates it with the current thread.
*
- * @param subject
- * @param principal
- * @param credential
+ * @param subject subject
+ * @param principal principal
+ * @param credential credential
*/
public void pushSubjectContext(final Subject subject, final Principal principal, final Object credential);
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/util/StAXUtils.java
===================================================================
--- spi/trunk/src/main/java/org/jboss/wsf/spi/util/StAXUtils.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/util/StAXUtils.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -64,8 +64,8 @@
/**
* Return a new factory so that the caller can set sticky parameters.
- * @param nsAware
- * @return
+ * @param nsAware true is nsAware
+ * @return XMLInputFactory
*/
public static XMLInputFactory createXMLInputFactory(boolean nsAware)
{
9 years, 9 months
JBossWS SVN: r19595 - in stack/cxf/trunk: modules/jaspi and 1 other directories.
by jbossws-commits@lists.jboss.org
Author: rsearls
Date: 2015-03-20 20:36:11 -0400 (Fri, 20 Mar 2015)
New Revision: 19595
Modified:
stack/cxf/trunk/modules/jaspi/pom.xml
stack/cxf/trunk/modules/jaspi/src/main/java/org/jboss/wsf/stack/cxf/jaspi/log/Loggers.java
stack/cxf/trunk/pom.xml
Log:
[JBWS-3878] resolve build WARNINGs for logging.
Modified: stack/cxf/trunk/modules/jaspi/pom.xml
===================================================================
--- stack/cxf/trunk/modules/jaspi/pom.xml 2015-03-20 15:40:46 UTC (rev 19594)
+++ stack/cxf/trunk/modules/jaspi/pom.xml 2015-03-21 00:36:11 UTC (rev 19595)
@@ -57,6 +57,10 @@
<artifactId>jboss-logging-processor</artifactId>
<scope>provided</scope>
</dependency>
+ <dependency>
+ <groupId>org.jboss.logging</groupId>
+ <artifactId>jboss-logging-annotations</artifactId>
+ </dependency>
<dependency>
<groupId>junit</groupId>
Modified: stack/cxf/trunk/modules/jaspi/src/main/java/org/jboss/wsf/stack/cxf/jaspi/log/Loggers.java
===================================================================
--- stack/cxf/trunk/modules/jaspi/src/main/java/org/jboss/wsf/stack/cxf/jaspi/log/Loggers.java 2015-03-20 15:40:46 UTC (rev 19594)
+++ stack/cxf/trunk/modules/jaspi/src/main/java/org/jboss/wsf/stack/cxf/jaspi/log/Loggers.java 2015-03-21 00:36:11 UTC (rev 19595)
@@ -24,10 +24,10 @@
import static org.jboss.logging.Logger.Level.WARN;
import org.jboss.logging.BasicLogger;
-import org.jboss.logging.Cause;
-import org.jboss.logging.LogMessage;
-import org.jboss.logging.Message;
-import org.jboss.logging.MessageLogger;
+import org.jboss.logging.annotations.Cause;
+import org.jboss.logging.annotations.LogMessage;
+import org.jboss.logging.annotations.Message;
+import org.jboss.logging.annotations.MessageLogger;
/**
* JBossWS-CXF log messages
Modified: stack/cxf/trunk/pom.xml
===================================================================
--- stack/cxf/trunk/pom.xml 2015-03-20 15:40:46 UTC (rev 19594)
+++ stack/cxf/trunk/pom.xml 2015-03-21 00:36:11 UTC (rev 19595)
@@ -77,6 +77,7 @@
<cxf.asm.version>3.3.1</cxf.asm.version>
<cxf.xjcplugins.version>3.0.2</cxf.xjcplugins.version>
<jboss-logging.version>3.1.2.GA</jboss-logging.version>
+ <jboss-logging-annotations.version>1.2.0.Final</jboss-logging-annotations.version>
<jboss-logging-processor.version>1.0.3.Final</jboss-logging-processor.version>
<jboss.jandex.version>1.0.3.Final</jboss.jandex.version>
<jboss.xb.version>2.0.3.GA</jboss.xb.version>
@@ -1220,6 +1221,11 @@
<artifactId>jboss-logging-processor</artifactId>
<version>${jboss-logging-processor.version}</version>
</dependency>
+ <dependency>
+ <groupId>org.jboss.logging</groupId>
+ <artifactId>jboss-logging-annotations</artifactId>
+ <version>${jboss-logging-annotations.version}</version>
+ </dependency>
<dependency>
<groupId>org.jboss.spec.javax.jms</groupId>
<artifactId>jboss-jms-api_1.1_spec</artifactId>
9 years, 9 months
JBossWS SVN: r19592 - projects/plugins/maven/archetypes/jaxws-codefirst/trunk.
by jbossws-commits@lists.jboss.org
Author: asoldano
Date: 2015-03-20 11:32:49 -0400 (Fri, 20 Mar 2015)
New Revision: 19592
Modified:
projects/plugins/maven/archetypes/jaxws-codefirst/trunk/pom.xml
Log:
[JBWS-3617] Bump to 1.1.0-SNAPSHOT and use latest parent
Modified: projects/plugins/maven/archetypes/jaxws-codefirst/trunk/pom.xml
===================================================================
--- projects/plugins/maven/archetypes/jaxws-codefirst/trunk/pom.xml 2015-03-20 15:29:07 UTC (rev 19591)
+++ projects/plugins/maven/archetypes/jaxws-codefirst/trunk/pom.xml 2015-03-20 15:32:49 UTC (rev 19592)
@@ -5,11 +5,11 @@
<parent>
<groupId>org.jboss.ws</groupId>
<artifactId>jbossws-parent</artifactId>
- <version>1.1.0.GA</version>
+ <version>1.2.0.CR1</version>
</parent>
<groupId>org.jboss.ws.plugins.archetypes</groupId>
<artifactId>jaxws-codefirst</artifactId>
- <version>1.0.1-SNAPSHOT</version>
+ <version>1.1.0-SNAPSHOT</version>
<packaging>maven-archetype</packaging>
<name>JBossWS-CXF Archetype - Simple JAX-WS Code First</name>
9 years, 9 months
JBossWS SVN: r19591 - in projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources: archetype-resources and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: asoldano
Date: 2015-03-20 11:29:07 -0400 (Fri, 20 Mar 2015)
New Revision: 19591
Modified:
projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/META-INF/maven/archetype-metadata.xml
projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/archetype-resources/pom.xml
Log:
[JBWS-3617] Updating descriptors to use jbossws-cxf 5.0.0.Beta2 and jaxws-tools-maven-plugin 1.2.0.Beta1 (so that we can also cut a beta release of the archetype using jbws 5)
Modified: projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/META-INF/maven/archetype-metadata.xml
===================================================================
--- projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/META-INF/maven/archetype-metadata.xml 2015-03-20 15:13:42 UTC (rev 19590)
+++ projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/META-INF/maven/archetype-metadata.xml 2015-03-20 15:29:07 UTC (rev 19591)
@@ -4,7 +4,7 @@
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
<requiredProperties>
<requiredProperty key="jbosswscxf" >
- <defaultValue>5.0.0-SNAPSHOT</defaultValue>
+ <defaultValue>5.0.0.Beta2</defaultValue>
</requiredProperty>
</requiredProperties>
<fileSets>
Modified: projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/archetype-resources/pom.xml
===================================================================
--- projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/archetype-resources/pom.xml 2015-03-20 15:13:42 UTC (rev 19590)
+++ projects/plugins/maven/archetypes/jaxws-codefirst/trunk/src/main/resources/archetype-resources/pom.xml 2015-03-20 15:29:07 UTC (rev 19591)
@@ -88,7 +88,7 @@
<plugin>
<groupId>org.wildfly.plugins</groupId>
<artifactId>wildfly-maven-plugin</artifactId>
- <version>1.0.0.Beta1</version>
+ <version>1.0.2.Final</version>
</plugin>
<plugin>
<artifactId>maven-war-plugin</artifactId>
@@ -100,8 +100,8 @@
<!-- JBossWS JAXWS tools plugins -->
<plugin>
<groupId>org.jboss.ws.plugins</groupId>
- <artifactId>maven-jaxws-tools-plugin</artifactId>
- <version>1.2.0-SNAPSHOT</version>
+ <artifactId>jaxws-tools-maven-plugin</artifactId>
+ <version>1.2.0.Beta1</version>
<configuration>
<verbose>true</verbose>
</configuration>
@@ -211,7 +211,7 @@
<pluginExecution>
<pluginExecutionFilter>
<groupId>org.jboss.ws.plugins</groupId>
- <artifactId>maven-jaxws-tools-plugin</artifactId>
+ <artifactId>jaxws-tools-maven-plugin</artifactId>
<versionRange>[1.1.1.Final,)</versionRange>
<goals>
<goal>wsconsume</goal>
9 years, 9 months
JBossWS SVN: r19590 - projects/plugins/maven/jaxws-tools/tags/jaxws-tools-1.2.0.Beta1.
by jbossws-commits@lists.jboss.org
Author: asoldano
Date: 2015-03-20 11:13:42 -0400 (Fri, 20 Mar 2015)
New Revision: 19590
Modified:
projects/plugins/maven/jaxws-tools/tags/jaxws-tools-1.2.0.Beta1/pom.xml
Log:
Fixing pom.xml
Modified: projects/plugins/maven/jaxws-tools/tags/jaxws-tools-1.2.0.Beta1/pom.xml
===================================================================
--- projects/plugins/maven/jaxws-tools/tags/jaxws-tools-1.2.0.Beta1/pom.xml 2015-03-20 15:10:50 UTC (rev 19589)
+++ projects/plugins/maven/jaxws-tools/tags/jaxws-tools-1.2.0.Beta1/pom.xml 2015-03-20 15:13:42 UTC (rev 19590)
@@ -8,7 +8,7 @@
<artifactId>jaxws-tools-maven-plugin</artifactId>
<packaging>maven-plugin</packaging>
- <version>1.2.0-SNAPSHOT</version>
+ <version>1.2.0.Beta1</version>
<!-- Parent -->
<parent>
9 years, 9 months
--- spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java 2015-03-21 00:36:11 UTC (rev 19595)
+++ spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/Deployment.java 2015-03-23 15:38:24 UTC (rev 19596)
@@ -28,12 +28,33 @@
*/
public interface Deployment extends Extensible
{
- /** Get the identifier for this deployment */
+ /**
+ * Get the identifier for this deployment
+ * @return deployment identifier
+ */
String getSimpleName();
- /** Get the class loader for this deployment */
+ /**
+ * Get the class loader for this deployment
+ * @return class loader for the deployment
+ */
ClassLoader getClassLoader();
-
- /** Get the service associated with this deployment */
+
+ /**
+ * Get the deployment type
+ * @return deployment type
+ */
+ DeploymentType getType();
+
+ /**
+ * Set the deployment type
+ * @param type deployment type
+ */
+ void setType(DeploymentType type);
+
+ /**
+ * Get the service associated with this deployment
+ * @return service for the deployment
+ */
Service getService();
}
Modified: spi/trunk/src/main/java/org/jboss/wsf/spi/deployment/DeploymentAspectManager.java
===================================================================